@@ -219,6 +219,8 @@ class Plinux:
     def run_cmd(self, cmd: str, sudo: bool = False, timeout: int = 30, ignore_errors: bool = False) -> SSHResponse:
         """Base method to execute SSH command on remote server
 
+        Exit codes: https://tldp.org/LDP/abs/html/exitcodes.html
+
         Args:
             cmd: SSH command
             sudo: Execute specified command as sudo user
@@ -246,20 +248,24 @@ class Plinux:
             err_ = err.read().decode().strip()
             parsed = SSHResponse(out=out_, err=err_, exited=exited, command=cmd)
 
-            # Log ERROR and WARNING
-            msg_err = f'{self.host:<14} | {parsed.exited}: Something went wrong!\n\tSTDERR: {parsed.stderr}'
-            if parsed.exited and not ignore_errors:  # Exit code != 0
-                self.logger.error(msg_err)
-                raise RemoteCommandExecutionError(parsed.stderr)
+            # Log ERROR / Exit code != 0 (operation is failed)
+            def_log = f'{self.host:<14} | {parsed.exited}:'
+            err_to_log = f'{def_log} STDERR:\n\t{parsed.stderr}' if parsed.stderr else def_log
+            if parsed.exited:
+                self.logger.error(err_to_log)
 
-            # Log WARNING
-            if parsed.stderr:  # Exit code != 0 and stderr contains message
-                self.logger.warning(msg_err)  # Exit code != 0 and no stderr
+                if not ignore_errors:  # Exit code != 0 and ignore_errors=True
+                    raise RemoteCommandExecutionError(parsed.stderr)
 
-            # Log response (INFO)
-            out_to_log = json.dumps(parsed.stdout, indent=4) if isinstance(parsed.stdout, dict) else parsed.stdout
-            msg_to_log = f'{parsed.exited}:\n\t{out_to_log}' if out_to_log else f'{parsed.exited}:'
-            self.logger.info(f'{self.host:<14} | {msg_to_log}')
+            # Log INFO / Exit code == 0 (operation is success)
+            else:
+                # Log WARNING
+                if parsed.stderr:  # Exit code != 0 and stderr contains message
+                    self.logger.warning(err_to_log)
+
+                out_to_log = json.dumps(parsed.stdout, indent=4) if isinstance(parsed.stdout, dict) else parsed.stdout
+                msg_to_log = f'{parsed.exited}:\n\t{out_to_log}' if out_to_log else f'{parsed.exited}:'
+                self.logger.info(f'{self.host:<14} | {msg_to_log}')
 
             return parsed
         finally:
@@ -427,9 +433,9 @@ class Plinux:
         return False
 
     def is_security_update_available(self) -> bool:
-        """Verify security update availability. Returns True is available. Otherwise returns False"""
+        """Verify security update availability. Returns True is available. Otherwise, returns False"""
 
-        result = self.run_cmd('apt-get upgrade -s | grep -i security')
+        result = self.run_cmd('apt-get upgrade -s | grep -i security', ignore_errors=True)
         return result.ok
 
     def get_package_info(self, package: str) -> dict:
@@ -499,22 +505,6 @@ class Plinux:
         result = self.run_cmd(cmd)
         return result.stdout
 
-    def get_service_status(self, name: str) -> str:
-        """Get service status
-
-        - systemctl is-active {name}
-
-        Args:
-            name: Service name
-
-        Returns:
-
-        """
-
-        cmd = f'systemctl is-active {name}'
-        result = self.run_cmd(cmd)
-        return result.stdout
-
     def is_service_active(self, name: str) -> bool:
         """Is service active?
 
@@ -528,7 +518,7 @@ class Plinux:
         """
 
         cmd = f'systemctl is-active --quiet {name}'
-        result = self.run_cmd(cmd)
+        result = self.run_cmd(cmd, ignore_errors=True)
         return result.ok
 
     def stop_service(self, name: str) -> bool:
@@ -660,7 +650,7 @@ class Plinux:
         result = self.run_cmd(cmd, sudo=True)
         return result.ok
 
-    def is_enabled(self, name: str) -> bool:
+    def is_service_enabled(self, name: str) -> bool:
         """Get unit service status
 
         - systemctl is-enabled {name}
@@ -670,7 +660,7 @@ class Plinux:
         """
 
         cmd = f'systemctl is-enabled {name}'
-        response = self.run_cmd(cmd).stdout
+        response = self.run_cmd(cmd, ignore_errors=True).stdout
 
         try:
             return True if 'enabled' in response else False
@@ -915,9 +905,22 @@ class Plinux:
         :return:
         """
 
-        if directory:
-            return self.run_cmd(f'grep -rn "{string}" {path}', sudo=sudo)
-        return self.run_cmd(f'grep -n "{string}" {path}', sudo=sudo)
+        self.logger.info(f'-> Grep line in file or directory')
+
+        cmd = f'grep -rn "{string}" {path}' if directory else f'grep -n "{string}" {path}'
+
+        result = self.run_cmd(cmd, sudo=sudo, ignore_errors=True)
+
+        match result.exited:
+            case 0:
+                self.logger.info(f'<- Pattern "{string}" found in {path}')
+            case 1:
+                self.logger.info(f'<- Pattern "{string}" not found')
+            case _:
+                self.logger.error(f'<- {result.stderr}')
+                raise RemoteCommandExecutionError
+
+        return result
 
     def change_line_in_file(self, path: str, old: str, new: str, sudo: bool = True):
         """Replace line and save file.
@@ -972,15 +975,16 @@ class Plinux:
         cmd = f'cmp -s {params} {file1} {file2}'
         result = self.run_cmd(cmd, sudo=sudo, ignore_errors=True)
 
-        if not result.exited:
-            self.logger.info('<- Files are equal')
-            return True
-        elif result.exited == 1:
-            self.logger.info('<- Files are different')
-            return False
-        else:
-            self.logger.error('<- File(s) not found')
-            raise FileNotFoundError(f'"{file1}" or "{file2}" not found')
+        match result.exited:
+            case 0:
+                self.logger.info(f'<- Files are equal')
+                return True
+            case 1:
+                self.logger.info(f'<- Files are different')
+                return False
+            case _:
+                self.logger.error(f'<- File(s) not found: {result.stderr}')
+                raise FileNotFoundError(f'"{file1}" or "{file2}" not found')
 
     def remove(self, path: str, sudo: bool = True) -> bool:
         """Remove file(s) and directories
@@ -1068,7 +1072,7 @@ class Plinux:
         """
 
         cmd = 'shutdown -r now'
-        result = self.run_cmd(cmd, sudo=True)
+        result = self.run_cmd(cmd, sudo=True, ignore_errors=True)
         return result.ok
 
     def shutdown(self) -> bool:
@@ -1081,7 +1085,7 @@ class Plinux:
         """
 
         cmd = 'shutdown -h now'
-        result = self.run_cmd(cmd, sudo=True)
+        result = self.run_cmd(cmd, sudo=True, ignore_errors=True)
         return result.ok
 
     #  ----------- Directory management -----------
@@ -1459,7 +1463,7 @@ class Plinux:
     netstat = get_netstat_info
     start = start_service
     stop = stop_service
-    status = get_service_status
+    status = is_service_active
     restart = restart_service
     version = get_os_version
     rm = remove
